@@ -14,12 +14,24 @@ Environment Variables
 * IOT_SECRETS   $IOT49/lib/secrets.py
 """
 
+"""
+Environment Variables
+
+  Name          Default
+* IOT           ~
+* IOT49         $IOT/iot49
+* IOT_DEVICES   ./devices:.:$IOT49/devices
+* IOT_LIBS      ./lib:.:$IOT49/lib
+* IOT_SECRETS   ./lib/secrets.py:./secrets.py:$IOT49/lib/secrets.py
+"""
+
 class Env:
 
     @staticmethod
-    def abs_path(path):
-        with cd(Env.iot_dir()):
-            return os.path.abspath(os.path.expanduser(os.path.expandvars(path)))
+    def expand_path(path):
+        # with cd(Env.iot_dir()):
+        #    return os.path.abspath(os.path.expanduser(os.path.expandvars(path)))
+        return os.path.expanduser(os.path.expandvars(path))
 
     @staticmethod
     def iot_dir():
@@ -29,18 +41,21 @@ class Env:
     def iot49_dir():
         return os.getenv('IOT49', os.path.join(Env.iot_dir(), 'iot49'))
 
-    @staticmethod
-    def iot_secrets():
-        return os.getenv('IOT_SECRETS', os.path.join(Env.iot49_dir(), 'libs/secrets.py'))
-    
     @staticmethod
     def iot_device_dirs():
-        return os.getenv('IOT_DEVICES', os.path.join(Env.iot49_dir(), 'devices')).split(':')
+        return [ './devices', '.' ] + os.getenv('IOT_DEVICES', os.path.join(Env.iot49_dir(), 'devices')).split(':')
 
     @staticmethod
     def iot_lib_dirs():
-        return os.getenv('IOT_LIBS', os.path.join(Env.iot49_dir(), 'libs')).split(':')
+        return [ './lib', '.' ] + os.getenv('IOT_LIBS', os.path.join(Env.iot49_dir(), 'lib')).split(':')
         
+    @staticmethod
+    def iot_secrets():
+        if 'IOT_SECRETS' in os.environ: return os.getenv('IOT_SECRETS')
+        for s in [ './lib/secrets', './secrets.py' ]:
+            if os.path.isfile(s): return s
+        return os.path.join(Env.iot49_dir(), 'lib/secrets.py')
+    
     @staticmethod
     def print_config():
         print("IOT:        ", Env.iot_dir())
@@ -55,4 +70,4 @@ if not os.getenv('IOT'):
     os.environ['IOT'] = '~'
 
 if not os.getenv('IOT49'):
-    os.environ['IOT49'] = Env.abs_path('$IOT/iot49')
+    os.environ['IOT49'] = Env.expand_path('$IOT/iot49')
